<?php

namespace App\Console;

use App\Console\Commands\Apollo;
use App\Console\Commands\CommunityMemberStatistics;
use App\Console\Commands\Downloads;
use App\Console\Commands\MusicImport;
use App\Console\Commands\PostCollectBean;
use App\Console\Commands\PostCreateBean;
use App\Console\Commands\PostStatistics;
use App\Console\Commands\PostYesterday;
use App\Console\Commands\TopicUseCount;
use App\Console\Commands\UpdatePostInfo;
use App\Console\Commands\UpdatePostStatus;
use App\Console\Commands\UpdateReplyCount;
use App\Console\Commands\UpdateTopicData;
use App\Console\Commands\UpdateTopicUseCount;
use App\Console\Commands\VirusAdd;
use App\Console\Commands\YesterdayGreatPost;
use Illuminate\Console\Scheduling\Schedule;
use Laravel\Lumen\Console\Kernel as ConsoleKernel;

class Kernel extends ConsoleKernel
{
    /**
     * The Artisan commands provided by your application.
     *
     * @var array
     */
    protected $commands = [
        Apollo::class,
        PostYesterday::class,
        Downloads::class,
        VirusAdd::class,
        PostStatistics::class,
        PostCreateBean::class,
        PostCollectBean::class,
        UpdatePostInfo::class,
        UpdatePostStatus::class,
        UpdateReplyCount::class,
        UpdateTopicUseCount::class,
        UpdateTopicData::class,
        TopicUseCount::class,
        CommunityMemberStatistics::class,
        MusicImport::class,
        YesterdayGreatPost::class
    ];

    /**
     * Define the application's command schedule.
     *
     * @param  \Illuminate\Console\Scheduling\Schedule $schedule
     * @return void
     */
    protected function schedule(Schedule $schedule)
    {
        $path = storage_path('logs/' . date('Y-m-d') . '-schedule.log');

        $schedule->command('download:download')
            ->everyMinute()
            ->withoutOverlapping()->appendOutputTo($path);

        $schedule->command('post:yesterday')
            ->dailyAt('00:10')
            ->withoutOverlapping()->appendOutputTo($path);
        $schedule->command('post:statistics')
            ->dailyAt('00:20')
            ->withoutOverlapping()->appendOutputTo($path);
        //统计前一天用户行为累加
        $schedule->command('member:statistics')
            ->dailyAt('00:05')
            ->withoutOverlapping()->appendOutputTo($path);
        //统计前一天最佳内容
        $schedule->command('post:yesterday-great')
            ->dailyAt('00:30')
            ->withoutOverlapping()->appendOutputTo($path);
        //内容生成U米
        $schedule->command('post:create_bean')
            ->everyFiveMinutes()
            ->withoutOverlapping()->appendOutputTo($path);
        //内容收取U米
        $schedule->command('post:collect_bean')
            ->everyFiveMinutes()
            ->withoutOverlapping()->appendOutputTo($path);

        //更新话题使用数
        $schedule->command('post:topic_use_count')
            ->everyFiveMinutes()
            ->withoutOverlapping()->appendOutputTo($path);
    }
}
